<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP" sourcelanguage="en">
<context>
    <name>ArrowToolOptionsBox</name>
    <message>
        <source>Pick:</source>
        <translation>選択オブジェクト：</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>Z:</source>
        <translation>Z:</translation>
    </message>
    <message>
        <source>SO:</source>
        <translation>重ね順:</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>回転</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>拡大率</translation>
    </message>
    <message>
        <source>Global:</source>
        <translation>全体：</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>水平：</translation>
    </message>
    <message>
        <source>V:</source>
        <translation>垂直：</translation>
    </message>
    <message>
        <source>Maintain:</source>
        <translation>値を固定:</translation>
    </message>
    <message>
        <source>Shear</source>
        <translation>シアー</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">基準点</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation type="vanished">ロック</translation>
    </message>
    <message>
        <source>(</source>
        <translation>(</translation>
    </message>
    <message>
        <source>)</source>
        <translation>)</translation>
    </message>
    <message>
        <source>Center Position</source>
        <translation>センター位置</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>位置:</translation>
    </message>
    <message>
        <source>Rotation:</source>
        <translation>回転:</translation>
    </message>
    <message>
        <source>Table</source>
        <translation>テーブル</translation>
    </message>
</context>
<context>
    <name>BrushTool</name>
    <message>
        <source>Thickness</source>
        <translation type="vanished">［太さ］</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation type="vanished">硬さ：</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation type="vanished">精度：</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation type="vanished">塗りの保護</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation type="vanished">プリセット：</translation>
    </message>
    <message>
        <source>Break Sharp Angles</source>
        <translation type="vanished">鋭角で線を分割</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation type="vanished">鉛筆モード</translation>
    </message>
    <message>
        <source>Pressure Sensitivity</source>
        <translation type="vanished">圧力感度</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation type="vanished">線端</translation>
    </message>
    <message>
        <source>Join</source>
        <translation type="vanished">角の形状</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation type="vanished">角の比率：</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="vanished">サイズ</translation>
    </message>
    <message>
        <source>Break</source>
        <translation type="vanished">鋭角で線を分割</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation type="vanished">鉛筆モード</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation type="vanished">圧力感知</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation type="vanished">平滑化：</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="vanished">中割り：</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="vanished">スナップ</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="vanished">&lt;カスタム&gt;</translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="vanished">無効</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation type="vanished">均等割り</translation>
    </message>
    <message>
        <source>In</source>
        <translation type="vanished">イーズイン</translation>
    </message>
    <message>
        <source>Out</source>
        <translation type="vanished">イーズアウト</translation>
    </message>
    <message>
        <source>In&amp;Out</source>
        <translation type="vanished">イーズインアウト</translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="vanished">低</translation>
    </message>
    <message>
        <source>Med</source>
        <translation type="vanished">中</translation>
    </message>
    <message>
        <source>High</source>
        <translation type="vanished">高</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation type="vanished">バット線端</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation type="vanished">丸型線端</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation type="vanished">突出線端</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation type="vanished">マイター結合</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation type="vanished">ラウンド結合</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation type="vanished">ベベル結合</translation>
    </message>
    <message>
        <source>Draw Order:</source>
        <translation type="vanished">線の重ね順:</translation>
    </message>
    <message>
        <source>Over All</source>
        <translation type="vanished">上に描く</translation>
    </message>
    <message>
        <source>Under All</source>
        <translation type="vanished">下に描く</translation>
    </message>
    <message>
        <source>Palette Order</source>
        <translation type="vanished">パレット順</translation>
    </message>
</context>
<context>
    <name>BrushToolOptionsBox</name>
    <message>
        <source>Preset Name</source>
        <translation>プリセット名</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>ControlPointEditorTool</name>
    <message>
        <source>Auto Select Drawing</source>
        <translation>レベルをまたいで選択</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation>スナップ</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>タイプ：</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>長方形</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>なげなわ</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <source>Med</source>
        <translation>中</translation>
    </message>
    <message>
        <source>High</source>
        <translation>高</translation>
    </message>
</context>
<context>
    <name>ControlPointSelection</name>
    <message>
        <source>Set Linear Control Point</source>
        <translation>コーナーポイントに変更</translation>
    </message>
    <message>
        <source>Set Nonlinear Control Point</source>
        <translation>スムーズポイントに変更</translation>
    </message>
</context>
<context>
    <name>DVGui::StyleIndexLineEdit</name>
    <message>
        <source>current</source>
        <translation>選択色</translation>
    </message>
</context>
<context>
    <name>EditTool</name>
    <message>
        <source>Scale Constraint:</source>
        <translation>拡大・縮小設定:</translation>
    </message>
    <message>
        <source>Auto Select Column</source>
        <translation>列を自動選択</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>グローバルキー</translation>
    </message>
    <message>
        <source>Lock Center X</source>
        <translation>基準点 [X]</translation>
    </message>
    <message>
        <source>Lock Center Y</source>
        <translation>基準点［Y］</translation>
    </message>
    <message>
        <source>Lock Position X</source>
        <translation>位置 ［X］</translation>
    </message>
    <message>
        <source>Lock Position Y</source>
        <translation>位置［Y］</translation>
    </message>
    <message>
        <source>Lock Rotation</source>
        <translation>回転</translation>
    </message>
    <message>
        <source>Lock Shear H</source>
        <translation>変形［横］</translation>
    </message>
    <message>
        <source>Lock Shear V</source>
        <translation>変形［縦］</translation>
    </message>
    <message>
        <source>Lock Scale H</source>
        <translation>拡大・縮小［横］</translation>
    </message>
    <message>
        <source>Lock Scale V</source>
        <translation>拡大・縮小［縦］</translation>
    </message>
    <message>
        <source>Lock Global Scale</source>
        <translation>拡大・縮小［全体］</translation>
    </message>
    <message>
        <source>X and Y Positions</source>
        <translation>X と Y の位置</translation>
    </message>
    <message>
        <source>Z Position</source>
        <translation>Z 位置</translation>
    </message>
    <message>
        <source>SO</source>
        <translation>重ね順</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>回転</translation>
    </message>
    <message>
        <source>Global Scale</source>
        <translation>拡大・縮小［全体］</translation>
    </message>
    <message>
        <source>Horizontal and Vertical Scale</source>
        <translation>拡大・縮小［横・縦］</translation>
    </message>
    <message>
        <source>Shear</source>
        <translation>シアー</translation>
    </message>
    <message>
        <source>Center Position</source>
        <translation>基準点位置</translation>
    </message>
    <message>
        <source>Active Axis</source>
        <translation>操作する軸</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>A/R</source>
        <translation>縦横比</translation>
    </message>
    <message>
        <source>Mass</source>
        <translation>面積</translation>
    </message>
    <message>
        <source>Column</source>
        <translation>列</translation>
    </message>
    <message>
        <source>Pegbar</source>
        <translation>タップ</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>拡大縮小</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>基準点</translation>
    </message>
    <message>
        <source>All</source>
        <translation>全て</translation>
    </message>
</context>
<context>
    <name>EraserTool</name>
    <message>
        <source>Size:</source>
        <translation>サイズ：</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>硬さ：</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>タイプ：</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>モード：</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>塗りの保護</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>反転</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>フレーム範囲</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation>鉛筆モード</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>通常</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>長方形</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>なげなわ</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>多角形</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>線</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>塗り</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>線と塗り</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>線分の自動検出</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation>均等割り</translation>
    </message>
    <message>
        <source>Ease In</source>
        <translation>後詰め</translation>
    </message>
    <message>
        <source>Ease Out</source>
        <translation>先詰め</translation>
    </message>
    <message>
        <source>Ease In/Out</source>
        <translation>両詰め</translation>
    </message>
</context>
<context>
    <name>FillTool</name>
    <message>
        <source>Frame Range</source>
        <translation>フレーム範囲</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>タイプ：</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>塗りの保護</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>モード：</translation>
    </message>
    <message>
        <source>Onion Skin</source>
        <translation>オニオンスキン</translation>
    </message>
    <message>
        <source>Fill Depth</source>
        <translation>塗りの浸透度</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>線分の自動検出</translation>
    </message>
    <message>
        <source>Autopaint Lines</source>
        <translation>含み塗り</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>通常</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>長方形</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>なげなわ</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>多角形</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>線</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>塗り</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>線と塗り</translation>
    </message>
    <message>
        <source>Maximum Gap</source>
        <translation>隙間の判定</translation>
    </message>
</context>
<context>
    <name>FingerTool</name>
    <message>
        <source>Size:</source>
        <translation>サイズ：</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>反転</translation>
    </message>
</context>
<context>
    <name>FullColorBrushTool</name>
    <message>
        <source>Thickness</source>
        <translation type="vanished">太さ</translation>
    </message>
    <message>
        <source>Pressure Sensitivity</source>
        <translation type="vanished">圧力感知</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation type="vanished">不透明度：</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>硬さ：</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>プリセット：</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>圧力感知</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>不透明度</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>消しゴムモード</translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation>透明部分の保護</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation>&lt;カスタム&gt;</translation>
    </message>
</context>
<context>
    <name>FullColorEraserTool</name>
    <message>
        <source>Size:</source>
        <translation>サイズ：</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>不透明度：</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>硬さ：</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>タイプ：</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>反転</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>フレーム範囲</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>通常</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>長方形</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>なげなわ</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>多角形</translation>
    </message>
</context>
<context>
    <name>FullColorFillTool</name>
    <message>
        <source>Fill Depth</source>
        <translation>塗りの浸透度</translation>
    </message>
</context>
<context>
    <name>HandToolOptionsBox</name>
    <message>
        <source>Reset Position</source>
        <translation>表示位置をリセット</translation>
    </message>
</context>
<context>
    <name>HookTool</name>
    <message>
        <source>Snap</source>
        <translation>スナップ</translation>
    </message>
</context>
<context>
    <name>MagnetTool</name>
    <message>
        <source>Size:</source>
        <translation>サイズ：</translation>
    </message>
</context>
<context>
    <name>PaintBrushTool</name>
    <message>
        <source>Size:</source>
        <translation>サイズ：</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>モード：</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>塗りの保護</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>線</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>塗り</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>線と塗り</translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation>透明部分の保護</translation>
    </message>
</context>
<context>
    <name>PinchTool</name>
    <message>
        <source>Size:</source>
        <translation>サイズ：</translation>
    </message>
    <message>
        <source>Corner:</source>
        <translation>拡がり角：</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手動</translation>
    </message>
</context>
<context>
    <name>PlasticTool</name>
    <message>
        <source>Build Skeleton</source>
        <translation>ボーン作成</translation>
    </message>
    <message>
        <source>Paint Rigid</source>
        <translation>固定ペイントブラシ</translation>
    </message>
    <message>
        <source>Animate</source>
        <translation>アニメート</translation>
    </message>
    <message>
        <source>Rigid</source>
        <translation>剛体</translation>
    </message>
    <message>
        <source>Flex</source>
        <translation>柔軟</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>モード：</translation>
    </message>
    <message>
        <source>Vertex Name:</source>
        <translation>頂点名：</translation>
    </message>
    <message>
        <source>Allow Stretching</source>
        <translation>ストレッチを許可</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>太さ</translation>
    </message>
    <message>
        <source>Keep Distance</source>
        <translation>距離を保持</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>グローバルキー</translation>
    </message>
    <message>
        <source>A group of skeletons already exists for current column. Replacing it will also substitute any existing vertex animation.

Do you want to continue?</source>
        <translation>現在の列には、既にボーンが存在します。
ボーンを置き換えることで、既存の頂点アニメーションも変更されます。
継続してよろしいですか？</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Copy Skeleton</source>
        <translation>ボーンをコピー</translation>
    </message>
    <message>
        <source>Paste Skeleton</source>
        <translation>ボーンを貼り付け</translation>
    </message>
    <message>
        <source>Delete Vertex</source>
        <translation>頂点を削除</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>キーを設定</translation>
    </message>
    <message>
        <source>Set Rest Key</source>
        <translation>停止キーを設定</translation>
    </message>
    <message>
        <source>Set Global Key</source>
        <translation>グローバルキーを設定</translation>
    </message>
    <message>
        <source>Set Global Rest Key</source>
        <translation>グローバル停止キーを設定</translation>
    </message>
    <message>
        <source>Show Mesh</source>
        <translation>メッシュ表示</translation>
    </message>
    <message>
        <source>Show Rigidity</source>
        <translation>剛性の表示</translation>
    </message>
    <message>
        <source>Show SO</source>
        <translation>重ね順の表示</translation>
    </message>
    <message>
        <source>Show Skeleton Onion Skin</source>
        <translation>ボーンをオニオンスキン表示</translation>
    </message>
    <message>
        <source>The previous vertex name will be discarded, and all associated keys will be lost.

Do you want to proceed?</source>
        <translation>既存の頂点名は破棄され、全ての関連するキーが削除されます。

継続してよろしいですか？</translation>
    </message>
    <message>
        <source>Edit Mesh</source>
        <translation>メッシュの編集</translation>
    </message>
    <message>
        <source>Snap To Mesh</source>
        <translation>メッシュにスナップ</translation>
    </message>
    <message>
        <source>Angle Bounds</source>
        <translation>角度の範囲を設定</translation>
    </message>
    <message>
        <source>Swap Edge</source>
        <translation>エッジをスワップ</translation>
    </message>
    <message>
        <source>Collapse Edge</source>
        <translation>エッジを削除</translation>
    </message>
    <message>
        <source>Split Edge</source>
        <translation>エッジを分割</translation>
    </message>
    <message>
        <source>Cut Mesh</source>
        <translation>メッシュをカット</translation>
    </message>
</context>
<context>
    <name>PlasticToolOptionsBox</name>
    <message>
        <source>Create Mesh</source>
        <translation>メッシュを作成</translation>
    </message>
    <message>
        <source>Skeleton:</source>
        <translation>ボーン：</translation>
    </message>
    <message>
        <source>SO</source>
        <translation>重ね順</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距離</translation>
    </message>
</context>
<context>
    <name>PrimitiveParam</name>
    <message>
        <source>Shape:</source>
        <translation>形状：</translation>
    </message>
    <message>
        <source>Thickness:</source>
        <translation>太さ：</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>不透明度：</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>硬さ：</translation>
    </message>
    <message>
        <source>Polygon Sides:</source>
        <translation>多角形の辺の数：</translation>
    </message>
    <message>
        <source>Auto Group</source>
        <translation>自動グループ化</translation>
    </message>
    <message>
        <source>Auto Fill</source>
        <translation>自動塗りつぶし</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>塗りの保護</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation>鉛筆モード</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>線端</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>角の形状</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>角の比率：</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>サイズ：</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation>スナップ</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>長方形</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation>円形</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>楕円形</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>直線</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>折れ線</translation>
    </message>
    <message>
        <source>Arc</source>
        <translation>円弧</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation>多角形</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation>バット線端</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation>丸型線端</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation>突出線端</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation>マイター結合</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation>ラウンド結合</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation>ベベル結合</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <source>Med</source>
        <translation>中</translation>
    </message>
    <message>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <source>MultiArc</source>
        <translation>連続円弧</translation>
    </message>
    <message>
        <source>Smooth</source>
        <translation>滑らかに連結</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>作成後に回転</translation>
    </message>
</context>
<context>
    <name>PumpTool</name>
    <message>
        <source>Size:</source>
        <translation>サイズ：</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation>精度：</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Min:</source>
        <translation>最小：</translation>
    </message>
    <message>
        <source>Max:</source>
        <translation>最大：</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>はい</translation>
    </message>
    <message>
        <source>No</source>
        <translation>いいえ</translation>
    </message>
    <message>
        <source>The copied selection cannot be pasted in the current drawing.</source>
        <translation>コピーした選択範囲は現在の画像に貼り付けできません。</translation>
    </message>
    <message>
        <source>The current column is locked.</source>
        <translation>現在の列はロックされています。</translation>
    </message>
    <message>
        <source>The current column is not visible in Camera Stand.</source>
        <translation type="vanished">選択した列はテーブルに非表示で、作業できません。</translation>
    </message>
    <message>
        <source>It is not possible to edit the audio column.</source>
        <translation>サウンド列は編集できません。</translation>
    </message>
    <message>
        <source>It is not possible to edit the Magpie column.</source>
        <translation type="vanished">MAGPIE列は編集できません。</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Level column.</source>
        <translation>現在のツールはレベルの列には使用できません。</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Mesh column.</source>
        <translation>現在のツールはメッシュ列には使用できません。</translation>
    </message>
    <message>
        <source>The current tool cannot be used in Level Strip mode.</source>
        <translation>現在のツールはレベル編集モードでは使用できません。</translation>
    </message>
    <message>
        <source>The current tool cannot be used to edit a motion path.</source>
        <translation>現在のツールはモーションパスの編集には使用できません。</translation>
    </message>
    <message>
        <source>The current level is not editable.</source>
        <translation>現在のレベルは編集不可能です。</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Vector Level.</source>
        <translation>現在のツールはベクトルレベルには使用できません。</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Toonz Level.</source>
        <translation>現在のツールはToonzレベルには使用できません。</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Raster Level.</source>
        <translation>現在のツールはラスターレベルには使用できません。</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Mesh Level.</source>
        <translation>現在のツールはメッシュレベルには使用できません。</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a mesh-deformed level</source>
        <translation>現在のツールはメッシュ変形されたレベルには使用できません</translation>
    </message>
    <message>
        <source>The current frame is locked: any editing is forbidden.</source>
        <translation>現在のフレームはロックされています：編集ができません。</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>貼り付け</translation>
    </message>
    <message>
        <source>Move Center</source>
        <translation>センター位置を移動</translation>
    </message>
    <message>
        <source>RGB Picker (R%1, G%2, B%3)</source>
        <translation>RGBスポイトツール （R%1, G%2, B%3）</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>グループ化</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>グループ解除</translation>
    </message>
    <message>
        <source>Move Group</source>
        <translation>グループを移動</translation>
    </message>
    <message>
        <source>Modify Fx Gadget  </source>
        <translation>エフェクト・ガジェットでパラメータを変更  </translation>
    </message>
    <message>
        <source>%1   Level : %2  Frame : %3</source>
        <translation>%1   レベル : %2  フレーム : %3</translation>
    </message>
    <message>
        <source>Modify Stroke Tool</source>
        <translation>アイロンツール</translation>
    </message>
    <message>
        <source>Modify Spline</source>
        <translation>スプラインを編集</translation>
    </message>
    <message>
        <source>Deform Raster</source>
        <translation>画像を変形</translation>
    </message>
    <message>
        <source>Transform Raster</source>
        <translation>画像を変形</translation>
    </message>
    <message>
        <source>Set Save Box : (X%1,Y%2,W%3,H%4)-&gt;(X%5,Y%6,W%7,H%8)</source>
        <translation>セーブボックスを設定 : (X%1,Y%2,W%3,H%4)-&gt;(X%5,Y%6,W%7,H%8)</translation>
    </message>
    <message>
        <source>The current column is hidden.</source>
        <translation>現在の列は非表示です。</translation>
    </message>
    <message>
        <source>Note columns can only be edited in the xsheet or timeline.</source>
        <translation>ノートレベルはタイムシート又はタイムライン上でのみ編集できます。</translation>
    </message>
    <message>
        <source> to Front</source>
        <translation> 最前面へ</translation>
    </message>
    <message>
        <source> to Forward</source>
        <translation> 前面へ</translation>
    </message>
    <message>
        <source> to Back</source>
        <translation> 最背面へ</translation>
    </message>
    <message>
        <source> to Backward</source>
        <translation> 背面へ</translation>
    </message>
    <message>
        <source>The selection cannot be updated. It is not editable.</source>
        <translation>選択ストロークを更新できません。レベルまたは列が編集不可に設定されています。</translation>
    </message>
    <message>
        <source>The selection cannot be deleted. It is not editable.</source>
        <translation>選択ストロークを削除できません。レベルまたは列が編集不可に設定されています。</translation>
    </message>
    <message>
        <source>The selection cannot be pasted. It is not editable.</source>
        <translation>選択ストロークを貼り付けできません。レベルまたは列が編集不可に設定されています。</translation>
    </message>
    <message>
        <source>The selection cannot be grouped. It is not editable.</source>
        <translation>選択ストロークをグループ化できません。レベルまたは列が編集不可に設定されています。</translation>
    </message>
    <message>
        <source>The selection cannot be entered. It is not editable.</source>
        <translation>選択グループを開けません。レベルまたは列が編集不可に設定されています。</translation>
    </message>
    <message>
        <source>The selection cannot be ungrouped. It is not editable.</source>
        <translation>選択グループをグループ解除できません。レベルまたは列が編集不可に設定されています。</translation>
    </message>
    <message>
        <source>The selection cannot be moved. It is not editable.</source>
        <translation>選択グループを移動できません。レベルまたは列が編集不可に設定されています。</translation>
    </message>
    <message>
        <source>Snap At Intersection</source>
        <translation>交点にスナップ</translation>
    </message>
</context>
<context>
    <name>RGBPickerTool</name>
    <message>
        <source>Type:</source>
        <translation>タイプ：</translation>
    </message>
    <message>
        <source>Passive Pick</source>
        <translation>マウス位置の色を拾う</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>通常</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>長方形</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>なげなわ</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>多角形</translation>
    </message>
</context>
<context>
    <name>RGBPickerToolOptionsBox</name>
    <message>
        <source>Pick Screen</source>
        <translation>スクリーン上から拾う</translation>
    </message>
</context>
<context>
    <name>RasterSelectionTool</name>
    <message>
        <source>No Antialiasing</source>
        <translation>ハードな輪郭を維持</translation>
    </message>
    <message>
        <source>Modify Savebox</source>
        <translation>セーブボックス編集モード</translation>
    </message>
</context>
<context>
    <name>RasterTapeTool</name>
    <message>
        <source>Type:</source>
        <translation>タイプ：</translation>
    </message>
    <message>
        <source>Distance:</source>
        <translation>距離：</translation>
    </message>
    <message>
        <source>Style Index:</source>
        <translation>スタイル番号：</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>不透明度：</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>フレーム範囲</translation>
    </message>
    <message>
        <source>Angle:</source>
        <translation>角度：</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>全体</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>長方形</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>なげなわ</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>多角形</translation>
    </message>
    <message>
        <source>current</source>
        <translation>選択色</translation>
    </message>
</context>
<context>
    <name>RotateTool</name>
    <message>
        <source>Rotate On Camera Center</source>
        <translation>カメラ中心点を基準にする</translation>
    </message>
</context>
<context>
    <name>RotateToolOptionsBox</name>
    <message>
        <source>Reset Rotation</source>
        <translation>回転をリセット</translation>
    </message>
</context>
<context>
    <name>RulerToolOptionsBox</name>
    <message>
        <source>X:</source>
        <comment>ruler tool option</comment>
        <translation>X：</translation>
    </message>
    <message>
        <source>Y:</source>
        <comment>ruler tool option</comment>
        <translation>Y：</translation>
    </message>
    <message>
        <source>W:</source>
        <comment>ruler tool option</comment>
        <translation></translation>
    </message>
    <message>
        <source>H:</source>
        <comment>ruler tool option</comment>
        <translation></translation>
    </message>
    <message>
        <source>A:</source>
        <comment>ruler tool option</comment>
        <translation></translation>
    </message>
    <message>
        <source>L:</source>
        <comment>ruler tool option</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <source>Type:</source>
        <translation>タイプ：</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>長方形</translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation>なげなわ</translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation>多角形</translation>
    </message>
</context>
<context>
    <name>SelectionToolOptionsBox</name>
    <message>
        <source>H:</source>
        <translation>横：</translation>
    </message>
    <message>
        <source>V:</source>
        <translation>縦：</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>回転</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>太さ</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>縦横比を固定</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>拡大率</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>位置</translation>
    </message>
</context>
<context>
    <name>ShiftTraceToolOptionBox</name>
    <message>
        <source>Reset Previous</source>
        <translation>前のコマの変形をリセット</translation>
    </message>
    <message>
        <source>Reset Following</source>
        <translation>後のコマの変形をリセット</translation>
    </message>
    <message>
        <source>Previous Drawing</source>
        <translation>前のコマ</translation>
    </message>
    <message>
        <source>Following Drawing</source>
        <translation>後のコマ</translation>
    </message>
</context>
<context>
    <name>SkeletonTool</name>
    <message>
        <source>Global Key</source>
        <translation>グローバルキー</translation>
    </message>
    <message>
        <source>Show Only Active Skeleton</source>
        <translation>アクティブなボーンのみ表示</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>モード：</translation>
    </message>
    <message>
        <source>Reset Pinned Center</source>
        <translation>固定ピンをリセット</translation>
    </message>
    <message>
        <source>Build Skeleton</source>
        <translation>ボーン作成</translation>
    </message>
    <message>
        <source>Animate</source>
        <translation>アニメート</translation>
    </message>
    <message>
        <source>Inverse Kinematics</source>
        <translation>逆運動学（IK)</translation>
    </message>
</context>
<context>
    <name>StylePickerTool</name>
    <message>
        <source>No current level.</source>
        <translation>レベルが選択されていません。</translation>
    </message>
    <message>
        <source>Current level has no available palette.</source>
        <translation>現在のレベルには有効なパレットがありません。</translation>
    </message>
    <message>
        <source>Palette must have more than one palette to be organized.</source>
        <translation>パレットの整理には２つ以上のページが必要です。</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>モード：</translation>
    </message>
    <message>
        <source>Passive Pick</source>
        <translation>マウス位置のスタイルを拾う</translation>
    </message>
    <message>
        <source>Organize Palette</source>
        <translation>パレットを整理</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>線</translation>
    </message>
    <message>
        <source>Areas</source>
        <translation>塗り</translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation>線と塗り</translation>
    </message>
</context>
<context>
    <name>StylePickerToolOptionsBox</name>
    <message>
        <source>With this option being activated, the picked style will be
moved to the end of the first page of the palette.</source>
        <translation>このオプションを有効にしてカラーモデルから色を拾っていくと、サンプルされた
スタイルがパレットの1ページ目の末尾に順番に移動します。</translation>
    </message>
</context>
<context>
    <name>ToonzRasterBrushTool</name>
    <message>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>硬さ：</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation>平滑化：</translation>
    </message>
    <message>
        <source>Draw Order:</source>
        <translation>線の重ね順:</translation>
    </message>
    <message>
        <source>Over All</source>
        <translation>上に描く</translation>
    </message>
    <message>
        <source>Under All</source>
        <translation>下に描く</translation>
    </message>
    <message>
        <source>Palette Order</source>
        <translation>パレット順</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>プリセット：</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation>&lt;カスタム&gt;</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>鉛筆モード</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>圧力感知</translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation>透明部分の保護</translation>
    </message>
</context>
<context>
    <name>ToonzVectorBrushTool</name>
    <message>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation>精度：</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation>平滑化：</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>プリセット：</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation>&lt;カスタム&gt;</translation>
    </message>
    <message>
        <source>Break</source>
        <translation>鋭角で線を分割</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>圧力感知</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>線端</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>角の形状</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>角の比率：</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>中割り：</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation>スナップ</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>無効</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation>均等割り</translation>
    </message>
    <message>
        <source>In</source>
        <translation>イーズイン</translation>
    </message>
    <message>
        <source>Out</source>
        <translation>イーズアウト</translation>
    </message>
    <message>
        <source>In&amp;Out</source>
        <translation>イーズインアウト</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <source>Med</source>
        <translation>中</translation>
    </message>
    <message>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation>バット線端</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation>丸型線端</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation>突出線端</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation>マイター結合</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation>ラウンド結合</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation>ベベル結合</translation>
    </message>
</context>
<context>
    <name>TrackerTool</name>
    <message>
        <source>Width:</source>
        <translation>幅：</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>高さ：</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X：</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y：</translation>
    </message>
</context>
<context>
    <name>TypeTool</name>
    <message>
        <source>Font:</source>
        <translation>フォント：</translation>
    </message>
    <message>
        <source>Style:</source>
        <translation>スタイル：</translation>
    </message>
    <message>
        <source>Vertical Orientation</source>
        <translation>縦書きにする</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>サイズ：</translation>
    </message>
</context>
<context>
    <name>VectorSelectionTool</name>
    <message>
        <source>Mode:</source>
        <translation>モード：</translation>
    </message>
    <message>
        <source>Preserve Thickness</source>
        <translation>線の太さを保持</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>線端</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>角の形状</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>角の比率：</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>通常</translation>
    </message>
    <message>
        <source>Selected Frames</source>
        <translation>選択フレーム</translation>
    </message>
    <message>
        <source>Whole Level</source>
        <translation>レベル全体</translation>
    </message>
    <message>
        <source>Same Style</source>
        <translation>同じスタイル</translation>
    </message>
    <message>
        <source>Same Style on Selected Frames</source>
        <translation>同じスタイル - 選択フレーム</translation>
    </message>
    <message>
        <source>Same Style on Whole Level</source>
        <translation>同じスタイル - レベル全体</translation>
    </message>
    <message>
        <source>Boundary Strokes</source>
        <translation>輪郭線</translation>
    </message>
    <message>
        <source>Boundaries on Selected Frames</source>
        <translation>輪郭線 - 選択フレーム</translation>
    </message>
    <message>
        <source>Boundaries on Whole Level</source>
        <translation>輪郭線 - 全てのレベル</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation>バット線端</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation>突出線端</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation>マイター結合</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation>ラウンド結合</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation>ベベル結合</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation>丸型線端</translation>
    </message>
    <message>
        <source>Include Intersection</source>
        <translation>交差選択</translation>
    </message>
</context>
<context>
    <name>VectorTapeTool</name>
    <message>
        <source>Smooth</source>
        <translation>滑らかに連結</translation>
    </message>
    <message>
        <source>Join Vectors</source>
        <translation>ベクターの結合</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距離：</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>モード：</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>タイプ：</translation>
    </message>
    <message>
        <source>Endpoint to Endpoint</source>
        <translation>端点から端点</translation>
    </message>
    <message>
        <source>Endpoint to Line</source>
        <translation>端点から線</translation>
    </message>
    <message>
        <source>Line to Line</source>
        <translation>線から線</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>通常</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation>長方形</translation>
    </message>
</context>
<context>
    <name>ZoomToolOptionsBox</name>
    <message>
        <source>Reset Zoom</source>
        <translation>ズームをリセット</translation>
    </message>
</context>
</TS>
